<?php
/*
Plugin Name: Horizontal Floating Social Sharing Bar
Plugin URI: http://www.rightyaleft.com/
Description: Shows a Cool horizontal sharing bar with selected social counter. It is fixed upon page scroll through out the Post.
Version: 1.0
Author: Likan Patra
Author URI: http://www.rightyaleft.com/
License: GPL2
*/

/*  
	Copyright 2012  Likan Patra  (email : likanpatra@gmail.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 2, as 
	published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// Exit on direct load 
if ( ! defined( 'ABSPATH' ) ) exit();

/**
 * Main Class
 * 
 * @since 1.0
 */
class ryal_Floating_Social_Sharing_Bar{

	/**
	 * Title of the Admin Page
	 * 
	 * @var string
	 */
	var $title;

	/**
	 * Slug of the Admin Page
	 * 
	 * @var string
	 */
	var $slug;

	/**
	 * Setting name of the Plugin
	 * 
	 * @var string
	 */
	var $setting;

	/**
	 * Social service buttons
	 * 
	 * @var array
	 */
	var $social_services = array();

	/**
	 * Constructor
	 */
	function __construct(){

		$this->title           = __( 'Floating Social Sharing Bar', 'ryal' );
		$this->slug            = 'ryal_fssb_settings';
		$this->setting         = 'ryal_floating_social_sharing_bar';
		$this->social_services = array(
			'Title',
			'Twitter',
			'Facebook',
			'Pinterest',
			'GooglePlus',
			'Digg',
			'LinkedIn',
			'StumbleUpon',
			'Buffer',
			'Comments'
		);

		/* Actions */
		add_action( 'admin_menu', array( $this, 'ryal_floating_menu' ) );
		add_action( 'admin_init', array( $this, 'ryal_register_settings' ) );
		add_action( 'template_redirect', array( $this, 'ryal_add_social_sharing_buttons' ) );

		/* Actication Hooks */
		register_activation_hook( __FILE__, array( $this, 'ryal_fssb_install' ) );
		register_deactivation_hook( __FILE__, array( $this, 'ryal_fssb_uninstall' ) );

	}

	/**
	 * Register Setting Page
	 * 
	 * @since 1.0
	 * 
	 * @return null
	 */
	function ryal_floating_menu(){

		$hook = add_options_page(
			$this->title,
			__( 'Floating Social Bar', 'ryal' ),
			'activate_plugins',
			$this->slug,
			array( $this, 'ryal_fshb_options_page' )
		);

	}

	/**
	 * Load default Options upon activation.
	 * 
	 * @since 1.0
	 * 
	 * @return null
	 */
	function ryal_fssb_install(){

		$ryal_options['ryal_enable_floating_social'] = 0; 
		$ryal_options['ryal_social_services']        = array_map( 'strtolower', $this->social_services );
		$ryal_options['ryal_title']                  = 'Share & Comment';
		$ryal_options['ryal_comments_zero']          = '0 Comments';
		$ryal_options['ryal_comments_one']           = '1 Comment';
		$ryal_options['ryal_comments_more']          = '% Comments';
		$ryal_options['ryal_topoffset']              = '0';
		$ryal_options['ryal_post_classname']         = 'hentry';
		$ryal_options['ryalBgColor']                 = 'FFFFFF';

		update_option( $this->setting, $ryal_options );

	}

	/**
	 * Remove options upon deavtivation.
	 * 
	 * @since 1.0
	 * 
	 * @return null
	 */
	function ryal_fssb_uninstall(){

		delete_option( $this->setting );

	}

	/**
	 * Registe the Setting
	 * 
	 * @since 1.1
	 * 
	 * @return null
	 */
	function ryal_register_settings(){

		register_setting( $this->setting, $this->setting, array( $this, 'ryal_sanitize_options' ) );

	}

	/**
	 * Sanitize Options upon save.
	 * 
	 * @since 1.1
	 * 
	 * @param  mixed $options submitted value
	 * @return mixed          sanitized value
	 */
	function ryal_sanitize_options( $options ){

		$new_options                               = array();
		$new_options['ryal_enable_floating_social'] = (int) (bool) $options['ryal_enable_floating_social'];
		$new_options['ryal_social_services']        = array();
		if ( ! empty( $options['ryal_social_services'] ) && is_array( $options['ryal_social_services'] ) ) {
			$all_socials = array_map( 'strtolower', $this->social_services );
			foreach ( $options['ryal_social_services'] as $service ) {
				if ( in_array( $service, $all_socials ) )
					$new_options['ryal_social_services'][] = $service;
			}
		}
		$new_options['ryal_title']      = wp_strip_all_tags( $options['ryal_title'] );
		$new_options['ryal_comments_zero']      = wp_strip_all_tags( $options['ryal_comments_zero'] );
		$new_options['ryal_comments_one']      = wp_strip_all_tags( $options['ryal_comments_one'] );
		$new_options['ryal_comments_more']      = wp_strip_all_tags( $options['ryal_comments_more'] );
		$new_options['ryal_topoffset']      = intval( $options['ryal_topoffset'] );
		$new_options['ryal_post_classname'] = sanitize_html_class( $options['ryal_post_classname'] );
		$new_options['ryalBgColor']         = preg_match( '/^[a-f0-9]{3,6}$/i', $options['ryalBgColor'] ) ? esc_attr( $options['ryalBgColor'] ) : 'FFFFFF';

		return $new_options;

	}

	/**
	 * Print the Setting Page.
	 * 
	 * @since 1.0
	 * 
	 * @return null
	 */
	function ryal_fshb_options_page(){

		$default = array(
			'ryal_enable_floating_social' => '',
			'ryal_social_services'        => array(),
			'ryal_title'                  => '',
			'ryal_comments_zero'          => '',
			'ryal_comments_one'          => '',
			'ryal_comments_more'          => '',
			'ryal_topoffset'              => '',
			'ryal_post_classname'         => '',
			'ryalBgColor'                 => '',
		);

		extract( wp_parse_args( get_option( $this->setting, array() ), $default ) );

		?>
		<div class="wrap">
			<?php screen_icon( 'plugins' ); ?>
			<h2><?php echo esc_html( $this->title ); ?></h2>
			<form action="options.php" method="POST" id="ryalForm">
				<h3><?php _e( 'Settings', 'ryal' );?></h3>
				<table class="form-table">
					<tr valing="top">
						<th scope="row"><label for="ryal_enable_floating_social"><?php _e( 'Enable the Plugin?', 'ryal' );?></label></th>
						<td>
							<select name="<?php echo esc_attr( $this->setting ); ?>[ryal_enable_floating_social]" id="ryal_enable_floating_social">
								<option value="1" <?php selected( $ryal_enable_floating_social, '1' );?>><?php _e( 'Yes', 'ryal' );?></option>
								<option value="0" <?php selected( $ryal_enable_floating_social, '0' );?>><?php _e( 'No', 'ryal' );?></option>
							</select>
							<p class="description"><?php _e( 'Enable or Disable the Plugin', 'ryal' ) ?></p>
						</td>
					</tr>
					<tr valing="top">
						<th scope="row"><label for=""><?php _e( 'Choose Social Buttons', 'ryal' );?></label></th>
						<td>
							<?php 
								foreach ( (array) $this->social_services as $social ) {
									$social_l = strtolower( $social );
									$id = 'ryal-service-'. esc_attr( $social_l );
									echo '<p>' . 
										 	'<input type="checkbox" name="' . esc_attr( $this->setting ) . '[ryal_social_services][]" value="' . esc_attr( $social_l ) . '" id="' . $id . '" ' . checked( in_array( $social_l, (array) $ryal_social_services ), true, false ) . '/>' .
										 	'<label for="'. $id .'"> '. $social .'</label>' .
										 '</p>';
								}
							?>
							<p class="description"><?php _e( 'Select the Social sharing buttons you want to show on the Horizontal bar.', 'ryal' ) ?></p>
						</td>
					</tr>
					<tr valing="top">
						<th scope="row"><label for="ryal_title"><?php _e( 'Title', 'ryal' );?></label></th>
						<td>
							<input type="text" name="<?php echo esc_attr( $this->setting ); ?>[ryal_title]" id="ryal_title" value="<?php echo esc_attr( $ryal_title ) ?>"/>
							<p class="description"><?php _e( '', 'ryal' ) ?></p>
						</td>
					</tr>
					<tr valing="top">
						<th scope="row"><label for=""><?php _e( 'Comment Strings', 'ryal' );?></label></th>
						<td>
							<input type="text" name="<?php echo esc_attr( $this->setting ); ?>[ryal_comments_zero]" id="ryal_comments_zero" size="8" value="<?php echo esc_attr( $ryal_comments_zero ) ?>"/>
							<input type="text" name="<?php echo esc_attr( $this->setting ); ?>[ryal_comments_one]" id="ryal_comments_one" size="8" value="<?php echo esc_attr( $ryal_comments_one ) ?>"/>
							<input type="text" name="<?php echo esc_attr( $this->setting ); ?>[ryal_comments_more]" id="ryal_comments_more" size="8" value="<?php echo esc_attr( $ryal_comments_more ) ?>"/>
							<p class="description"><?php _e( 'Enter comments strings for Zero Comments, One Comments and More Comments', 'ryal' ) ?></p>
						</td>
					</tr>
					<tr valing="top">
						<th scope="row"><label for="ryal_topoffset"><?php _e( 'Top Offset', 'ryal' );?></label></th>
						<td>
							<input type="text" name="<?php echo esc_attr( $this->setting ); ?>[ryal_topoffset]" id="ryal_topoffset" size="4" value="<?php echo esc_attr( $ryal_topoffset ) ?>"/> <em>px</em>
							<p class="description"><?php _e( 'Top offset when Fixed position. normatlly it is <code>0</code> <br/> while scrolling the window, you may have your own fixed floating navigation menus. To avoid the conflicts, this option is helps you to set the top offset.', 'ryal' ) ?></p>
						</td>
					</tr>
					<tr valing="top">
						<th scope="row"><label for="ryal_post_classname"><?php _e( 'Post Class Name (Optional)' ); ?></label></th>
						<td>
							<input type="text" name="<?php echo esc_attr( $this->setting ); ?>[ryal_post_classname]" id="ryal_post_classname" size="10" value="<?php echo esc_attr( $ryal_post_classname ); ?>"/>
							<p class="description"><?php _e( 'Common Class name of your Post. This is <code>hentry</code> in most cases. However, if you have different class name, add the class name here without <code>.</code> in front of class name.', 'ryal' ); ?></p>
						</td>
					</tr>
					<tr valing="top">
						<th scope="row"><label for="ryalBgColor"><?php _e( 'Background Color' ); ?></label></th>
						<td>
							# <input type="text" name="<?php echo esc_attr( $this->setting ); ?>[ryalBgColor]" id="ryalBgColor" size="10" value="<?php echo esc_attr( $ryalBgColor ); ?>"/>
							<p class="description"><?php _e( 'Background color of the Horizontal bar.', 'ryal' ); ?></p>
						</td>
					</tr>
					<tr valing="top">
						<td colspan="2">
							<?php settings_fields( $this->setting ); ?>
							<?php submit_button(); ?>
						</td>
					</tr>
				</table>
			</form>
			<p>Coded by <a href="http://www.rightyaleft.com/" target="_blank">Likan Patra</a>. Please share this Plugin.</p>
		</div>
		<?php
	}

	/**
	 * Add Scripts, CSS and HTML to Single Post pages
	 * 
	 * @since 1.0
	 * 
	 * @return null if not single post
	 */
	function ryal_add_social_sharing_buttons(){

		if ( ! is_singular( 'post' ) )
			return;

		wp_enqueue_script( 'jquery' );

		add_action( 'wp_head', array( $this, 'ryal_insert_socialcss' ) );
		add_action( 'wp_footer', array( $this, 'ryal_insert_socialscripts' ) );

		add_filter( 'the_content', array( $this,'ryal_insert_socialhtml' ) );

	}

	/**
	 * Add Social Sharing HTML to Top of Content.
	 * 
	 * @since 1.0
	 * 
	 * @param  string $content Post Content.
	 * @return string          Social sharing html + Post Content.
	 */
	function ryal_insert_socialhtml( $content ){

		$social_html = $this->ryal_get_socialsharinghtml();
		return $social_html . $content;

	}

	/**
	 * Print Social Scripts on Footer
	 * 
	 * @since 1.0
	 * 
	 * @return null 
	 */
	function ryal_insert_socialscripts(){

		$ryal_option      = get_option( $this->setting );
		$ryal_post_classs = empty( $ryal_option['ryal_post_classname'] ) ? 'hentry' : stripslashes( $ryal_option['ryal_post_classname'] );
		$ryal_offset      = empty( $ryal_option['ryal_topoffset'] ) ? 0 : intval( $ryal_option['ryal_topoffset'] );

		if ( count( $ryal_option['ryal_social_services'] ) != 0 && $ryal_option['ryal_enable_floating_social'] ) {

			$scripts     = '';
			$social_scripts = array(
				'twitter'     => '(function(a,b,c){var d=a.getElementsByTagName(b)[0];if(!a.getElementById(c)){a=a.createElement(b);a.id=c;a.src="//platform.twitter.com/widgets.js";d.parentNode.insertBefore(a,d)}})(document,"script","twitter-wjs");',
				'googleplus'  => '(function(){var a=document.createElement("script");a.type="text/javascript";a.async=true;a.src="https://apis.google.com/js/plusone.js";var b=document.getElementsByTagName("script")[0];b.parentNode.insertBefore(a,b)})();',
				'stumbleupon' => '(function(){var a=document.createElement("script");a.type="text/javascript";a.async=true;a.src="https://platform.stumbleupon.com/1/widgets.js";var b=document.getElementsByTagName("script")[0];b.parentNode.insertBefore(a,b)})();',
				'digg'        => '(function(){var a=document.createElement("script"),b=document.getElementsByTagName("script")[0];a.type="text/javascript";a.async=true;a.src="http://widgets.digg.com/buttons.js";b.parentNode.insertBefore(a,b)})();',
				'pinterest'   => '(function(){var a=document.createElement("script");a.type="text/javascript";a.async=true;a.src="//assets.pinterest.com/js/pinit.js";var b=document.getElementsByTagName("script")[0];b.parentNode.insertBefore(a,b)})();',
				'linkedin'    => '(function(){var a=document.createElement("script");a.type="text/javascript";a.async=true;a.src="//platform.linkedin.com/in.js";var b=document.getElementsByTagName("script")[0];b.parentNode.insertBefore(a,b)})();',
				'buffer'      => '(function(){var a=document.createElement("script");a.type="text/javascript";a.async=true;a.src="http://static.bufferapp.com/js/button.js";var b=document.getElementsByTagName("script")[0];b.parentNode.insertBefore(a,b)})();',
			);

			foreach ( (array) $ryal_option['ryal_social_services'] as $service ) {
				if ( array_key_exists( strtolower( $service ), $social_scripts ) )
					$scripts .= $social_scripts[ strtolower($service) ] . "\n";
			}

			echo <<<ryalSCRIPTS
<script type='text/javascript'>
/*<![CDATA[*/
{$scripts}/*]]>*/
</script>
<script type='text/javascript'>
/*<![CDATA[*/
var ryal_offset = {$ryal_offset};
jQuery(document).ready(function (b) {
	var a = b("#ryalSocialFloat");
	a.wrap('<div id="ryalSocialPlaceholder"></div>').closest("#ryalSocialPlaceholder").height(a.outerHeight());
	a.width(a.outerWidth());
	e = a.offset().top - ryal_offset;
	b(window).scroll(function() {
		d = b(this).scrollTop();
		d >= e ? a.addClass("ryalFloatSocial") : a.removeClass("ryalFloatSocial");
		f = b(".{$ryal_post_classs}");
		if(f.length != 0) {
			c = f.outerHeight() + f.offset().top;
			d >= c ? a.stop().animate({
				top: "-150px"
			}) : a.stop().animate({
				top: ryal_offset + "px"
			});
		} else d >= e ? a.css("top", ryal_offset + "px") : a.css("top", "0");
	});
});
/*]]>*/
</script>
ryalSCRIPTS;

		}
	}

	/**
	 * Build Social Sharing HTML and returns it.
	 * 
	 * @since 1.0
	 * 
	 * @return string Social Sharing HTML.
	 */
	function ryal_get_socialsharinghtml(){

		$ryal_option = get_option( $this->setting );

		if ( count( $ryal_option['ryal_social_services'] ) != 0 && $ryal_option['ryal_enable_floating_social'] ) {

			global $post;
			$post_title    = $post->post_title;
			$post_url      = get_permalink( $post->ID );
			$post_image    = $this->get_post_image();
			
			// OB Shit!!!!!!!!
			ob_start();
			comments_popup_link( $ryal_option['ryal_comments_zero'], $ryal_option['ryal_comments_one'],$ryal_option['ryal_comments_more'] );
			$comments_link = ob_get_clean();

			$social_html = array(
				'title'       => '<td class="share-title">' . esc_html( $ryal_option['ryal_title'] ) . '</td>',
				'facebook'    => sprintf( '<td class="share-facebook"><iframe src="//www.facebook.com/plugins/like.php?href=%s&send=false&layout=button_count&width=80&show_faces=false&action=like&colorscheme=light&font&height=21" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:80px; height:21px;" allowTransparency="true"></iframe></td>', urlencode( $post_url ) ),
				'twitter'     => sprintf( '<td class="share-twitter"><a href="https://twitter.com/share" class="twitter-share-button" data-url="%s" data-text="%s">Tweet</a></td>', esc_attr( $post_url ), esc_attr( $post_title ) ),
				'googleplus'  => sprintf( '<td class="share-gplusone"><div class="g-plusone" data-size="medium" data-href="%s"></div></td>', esc_attr( $post_url ) ),
				'stumbleupon' => sprintf( '<td class="share-stumble"><su:badge layout="1" location="%s"></su:badge></td>', esc_attr( $post_url ) ),
				'digg'        => '<td class="share-digg"><a class="DiggThisButton DiggCompact"></a></td>',
				'pinterest'   => sprintf( '<td class="share-pinit"><a href="http://pinterest.com/pin/create/button/?url=%s&media=%s&description=%s" class="pin-it-button" count-layout="horizontal"><img border="0" src="//assets.pinterest.com/images/PinExt.png" title="Pin It" /></a></td>', urlencode( $post_url ), urlencode( $post_image ), urlencode( $this->get_post_excerpt( 500 ) ) ),
				'linkedin'    => sprintf( '<td class="share-linkedin"><script type="IN/Share" data-url="%s" data-counter="right"></script></td>', esc_attr( $post_url ) ),
				'buffer'      => sprintf( '<td class="share-buffer"><a href="http://bufferapp.com/add" class="buffer-add-button" data-text="%s" data-url="%s" data-count="horizontal" data-picture="%s">Buffer</a></td>', esc_attr( $post_title ), esc_attr( $post_title ), esc_attr( $post_image ) ),
				'comments'    => '<td class="share-comments">' . $comments_link . '</td>',
			);
			
			$html          = "<div id=\"ryalSocialFloat\" class=\"ryalSocialFloat\">\n<table  width=\"100%\" class=\"ryalSocialFloat\">\n<tr>\n";

			foreach ( (array) $ryal_option['ryal_social_services'] as $service ) {
				if ( array_key_exists( strtolower( $service ), $social_html ) )
					$html .= $social_html[ strtolower( $service ) ] . "\n";
			}

			$html .= "</tr>\n</table>\n</div>";

			return $html;

		}

	}

	/**
	 * Insert CSS on wp_head.
	 * 
	 * @since 1.0
	 * 
	 * @return null 
	 */
	function ryal_insert_socialcss(){

		$ryal_option = get_option( $this->setting );
		$color      = empty( $ryal_option['ryalBgColor'] ) ? 'FFFFFF' : $ryal_option['ryalBgColor'];

		if ( count( $ryal_option['ryal_social_services'] ) != 0 && $ryal_option['ryal_enable_floating_social'] ) {

			echo <<<ryalCSS
<style type='text/css'>
/*<![CDATA[*/
#ryalSocialFloat {
	clear:both;
	padding: 6px 0;
	display:block;
	background:#{$color};
}
.ryalSocialFloat{
	margin:0 !important;
}
#ryalSocialFloat td{
	padding:4px;
	margin:0;
	border:none;
	vertical-align:top;
}
#ryalSocialFloat td iframe{
	max-width:82px;
	width:82px !important;
}
#ryalSocialFloat td.share-gplusone *{
	max-width:80px !important;
}
#ryalSocialFloat td.share-pinit > a {
	vertical-align:top !important;
}
#ryalSocialFloat.ryalFloatSocial{
	position: fixed;
	top:0;
	z-index:999;
	border-bottom:1px solid #ccc;
	-webkit-box-shadow:0 1px 1px rgba(0,0,0,0.15);
	-moz-box-shadow:0 1px 1px rgba(0,0,0,0.15);
	box-shadow:0 1px 1px rgba(0,0,0,0.15);
}
/*]]>*/
</style>
ryalCSS;

		}

	}

	/**
	 * Get the Featured Image OR First Image in the Post.
	 * 
	 * @since 1.1
	 * 
	 * @return string Featured Image OR First Image in the Post.
	 */
	function get_post_image() {

		global $post;
		$post_thumbnail_url = '';
		if( has_post_thumbnail( $post->ID ) ) { 
			$post_thumbnail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ),  'single-post-thumbnail' );  
			$post_thumbnail_url = $post_thumbnail[0];
		} else {
			preg_match_all( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches );
			if ( isset( $matches[1] ) && isset( $matches[1][0] ) )
				$post_thumbnail_url = $matches[1][0];
		}

		return $post_thumbnail_url;

	}

	/**
	 * Get the Post excerpts of specifed length.
	 * 
	 * @since 1.1
	 * 
	 * @param  integer $length Length of the post content.
	 * @return string          Post excerpts.
	 */
	function get_post_excerpt( $length = 100 ) {
		
		$content = wp_strip_all_tags( get_the_content(), true );

		return substr( $content, 0, $length );

	}

}

/* New Instance */
new ryal_Floating_Social_Sharing_Bar;